import setuptools
import os.path

import svncl

app_path = os.path.dirname(svncl.__file__)

with open(os.path.join(app_path, 'resources', 'README.rst')) as f:
      long_description = f.read()

with open(os.path.join(app_path, 'resources', 'requirements.txt')) as f:
      install_requires = map(lambda s: s.strip(), f)

setuptools.setup(
      name='svncl',
      version=svncl.__version__,
      description="Generate changelog text between HEAD and the last tag.",
      long_description=long_description,
      classifiers=[],
      keywords='subversion svn changelog',
      author='Dustin Oprea',
      author_email='myselfasunder@gmail.com',
      url='https://github.com/dsoprea/SvnCl',
      license='GPL 2',
      packages=setuptools.find_packages(exclude=['dev']),
      include_package_data=True,
      zip_safe=False,
      install_requires=install_requires,
      package_data={
          'svncl': ['resources/README.rst',
                    'resources/requirements.txt',
                    'resources/scripts/*'],
      },
      scripts=[
          'svncl/resources/scripts/svncl',
      ],
)



import datetime

import svn
import svn.local
import svn.remote

def generate(wd_path, tag_directory_url):
    s_tag = svn.remote.RemoteClient(tag_directory_url)
    tags = list(s_tag.log_default(limit=1))

    if not tags:
        raise ValueError("No tags found.")

    last_tag = tags[0]
    s_wd = svn.local.LocalClient(wd_path)
    search_start_dt = last_tag.date + datetime.timedelta(seconds=1)
    for e in s_wd.log_default(timestamp_from_dt=search_start_dt):
        yield e.msg.rstrip()
